@@ -24,7 +24,6 @@
 		59 Temple Place - Suite 330
 		Boston, MA  02111-1307, USA
 
-	$Id: dga_check.h,v 1.4 2000/12/05 06:33:44 taniwha Exp $
 */
 
 #ifndef __dga_check_h_
@@ -32,7 +31,7 @@
 
 #include <X11/Xlib.h>
 
-#include "qtypes.h"
+#include "QF/qtypes.h"
 
 /*
   VID_CheckDGA
